########################
Config regions/languages
########################

The platforms page of the config tab allows you to set region and language preferences. The order here is important! It
will determine how preferred each region/language is.

Note that if no platforms are selected, you will see nothing here! Make sure to check one.

.. image:: ../images/config_regions_languages.png
